@@ -37,7 +37,9 @@
 #include <canvas/gcp-canvas-bpath.h>
 #include <canvas/gcp-canvas-pango.h>
 #include <gcu/element.h>
-#include <goffice/math/go-math.h>
+#ifndef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/math/go-math.h>
+#endif
 #include <openbabel/mol.h>
 #include <glib/gi18n-lib.h>
 #include <cstdlib>
@@ -346,7 +348,9 @@ void Atom::Add (GtkWidget* w) const
 		const_cast <Atom *> (this)->m_HLayout = pango_layout_new (pc);
 	}
 	if (m_FontName != pView->GetFontName ()) {
+		const_cast <Atom *> (this)->m_FontName = pView->GetFontName ();
 		pango_layout_set_font_description (m_Layout, pView->GetPangoFontDesc ());
+		pango_layout_set_font_description (m_HLayout, pView->GetPangoFontDesc ());
 		pango_layout_set_text (m_Layout, "l", 1);
 		PangoLayoutIter* iter = pango_layout_get_iter (m_Layout);
 		const_cast <Atom *> (this)->m_ascent = pango_layout_iter_get_baseline (iter) / PANGO_SCALE;
@@ -478,16 +482,18 @@ void Atom::Add (GtkWidget* w) const
 		g_object_set_data (G_OBJECT (group), "symbol", item);
 		g_object_set_data (G_OBJECT (item), "object", (void *) this);
 		g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
-		item = gnome_canvas_item_new (
-							group,
-							gnome_canvas_pango_get_type (),
-							"x", x - m_lbearing + m_xHOffs,
-							"y", y - m_ascent + m_CHeight + m_yHOffs,
-							"layout", m_HLayout,
-						NULL);
-		g_object_set_data (G_OBJECT (group), "hydrogens", item);
-		g_object_set_data (G_OBJECT (item), "object", (void *) this);
-		g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
+		if (GetAttachedHydrogens ()) {
+			item = gnome_canvas_item_new (
+								group,
+								gnome_canvas_pango_get_type (),
+								"x", x - m_lbearing + m_xHOffs,
+								"y", y - m_ascent + m_CHeight + m_yHOffs,
+								"layout", m_HLayout,
+							NULL);
+			g_object_set_data (G_OBJECT (group), "hydrogens", item);
+			g_object_set_data (G_OBJECT (item), "object", (void *) this);
+			g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
+		}
 	} else {
 		item = gnome_canvas_item_new (
 								group,
@@ -1046,7 +1052,7 @@ int Atom::GetChargePosition (unsigned char& Pos, double Angle, double& x, double
 			Pos = 0;
 			angle = m_AngleList.front();
 			double max = 0.0;
-			n = m_AngleList.end ();
+			end = m_AngleList.end ();
 			//if we are there, there are at least two bonds
 			for (n = m_AngleList.begin (), n++; n != end; n++) {
 				if (*n - angle > max) {
@@ -1666,8 +1672,24 @@ xmlNodePtr Atom::Save (xmlDocPtr xml) const
 		xmlNewProp (node, (xmlChar*) "show-symbol", (xmlChar*) "true");
 	}
 	if (m_HPosStyle != AUTO_HPOS) {
-		xmlNewProp (node, (xmlChar*) "H-position",
-					(xmlChar*) ((m_HPosStyle == LEFT_HPOS)? "left": "right"));
+		char const *pos;
+		switch (m_HPosStyle) {
+		default:
+		case RIGHT_HPOS:
+			pos = "right";
+			break;
+		case LEFT_HPOS:
+			pos = "left";
+			break;
+		case TOP_HPOS:
+			pos = "top";
+			break;
+		case BOTTOM_HPOS:
+			pos = "bottom";
+			break;
+		}
+		xmlNewProp (node, reinterpret_cast <xmlChar const*> ("H-position"),
+					reinterpret_cast <xmlChar const*> (pos));
 	}
 	return node;
 }
@@ -1749,6 +1771,12 @@ bool Atom::Load (xmlNodePtr node)
 			m_HPosStyle = LEFT_HPOS;
 		else if (!strcmp (buf, "right"))
 			m_HPosStyle = RIGHT_HPOS;
+		else if (!strcmp (buf, "top"))
+			m_HPosStyle = TOP_HPOS;
+		else if (!strcmp (buf, "bottom"))
+			m_HPosStyle = BOTTOM_HPOS;
+		else // who know?
+			m_HPosStyle = AUTO_HPOS;
 		xmlFree (buf);
 		Update ();
 	}
