@@ -4,7 +4,7 @@
  * GChemPaint library
  * reaction-arrow.cc 
  *
- * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -33,6 +33,7 @@
 #include "theme.h"
 #include "view.h"
 #include "widgetdata.h"
+#include <gcu/objprops.h>
 #include <canvas/gcp-canvas-group.h>
 #include <canvas/gcp-canvas-line.h>
 #include <glib/gi18n-lib.h>
@@ -40,6 +41,7 @@
 #include <cstring>
 
 using namespace gcu;
+using namespace std;
 
 namespace gcp {
 
@@ -64,7 +66,7 @@ ReactionArrow::~ReactionArrow ()
 		m_End->RemoveArrow (this);
 }
 
-xmlNodePtr ReactionArrow::Save (xmlDocPtr xml)
+xmlNodePtr ReactionArrow::Save (xmlDocPtr xml) const
 {
 	xmlNodePtr parent, node;
 	node = xmlNewDocNode (xml, NULL, (xmlChar*) "reaction-arrow", NULL);
@@ -152,7 +154,7 @@ bool ReactionArrow::Load (xmlNodePtr node)
 	return false;
 }
 
-void ReactionArrow::Add (GtkWidget* w)
+void ReactionArrow::Add (GtkWidget* w) const
 {
 	WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (w), "data");
 	if (pData->Items[this] != NULL)
@@ -179,7 +181,7 @@ void ReactionArrow::Add (GtkWidget* w)
 										"arrow_shape_c", pTheme->GetArrowHeadC (),
 										"last_arrowhead_style", (unsigned char) ARROW_HEAD_BOTH,
 										NULL);
-			g_object_set_data (G_OBJECT (item), "object", this);
+			g_object_set_data (G_OBJECT (item), "object", (void *) this);
 			g_object_set_data (G_OBJECT (group), "arrow", item);
 			g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
 			break;
@@ -203,7 +205,7 @@ void ReactionArrow::Add (GtkWidget* w)
 								"arrow_shape_c", pTheme->GetArrowHeadC (),
 								"last_arrowhead_style", (unsigned char) ARROW_HEAD_LEFT,
 								NULL);
-			g_object_set_data (G_OBJECT (item), "object", this);
+			g_object_set_data (G_OBJECT (item), "object", (void *) this);
 			g_object_set_data (G_OBJECT (group), "direct", item);
 			g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
 			points->coords[2] = m_x * pTheme->GetZoomFactor () + pTheme->GetArrowDist () / 2 * sin (dAngle);
@@ -222,7 +224,7 @@ void ReactionArrow::Add (GtkWidget* w)
 								"arrow_shape_c", pTheme->GetArrowHeadC (),
 								"last_arrowhead_style", (unsigned char) ARROW_HEAD_LEFT,
 								NULL);
-			g_object_set_data (G_OBJECT (item), "object", this);
+			g_object_set_data (G_OBJECT (item), "object", (void *) this);
 			g_object_set_data (G_OBJECT (group), "reverse", item);
 			g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
 			break;
@@ -247,7 +249,7 @@ void ReactionArrow::Add (GtkWidget* w)
 								"arrow_shape_c", pTheme->GetArrowHeadC (),
 								"last_arrowhead_style", (unsigned char) ARROW_HEAD_BOTH,
 								NULL);
-			g_object_set_data (G_OBJECT (item), "object", this);
+			g_object_set_data (G_OBJECT (item), "object", (void *) this);
 			g_object_set_data (G_OBJECT (group), "direct", item);
 			g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
 			points->coords[2] = m_x * pTheme->GetZoomFactor () + pTheme->GetArrowDist () / 2 * sin (dAngle);
@@ -266,7 +268,7 @@ void ReactionArrow::Add (GtkWidget* w)
 								"arrow_shape_c", pTheme->GetArrowHeadC (),
 								"last_arrowhead_style", (unsigned char) ARROW_HEAD_BOTH,
 								NULL);
-			g_object_set_data (G_OBJECT (item), "object", this);
+			g_object_set_data (G_OBJECT (item), "object", (void *) this);
 			g_object_set_data (G_OBJECT (group), "reverse", item);
 			g_signal_connect (G_OBJECT (item), "event", G_CALLBACK (on_event), w);
 			break;
@@ -276,20 +278,21 @@ void ReactionArrow::Add (GtkWidget* w)
 	gnome_canvas_points_free (points);
 }
 
-void ReactionArrow::Update (GtkWidget* w)
+void ReactionArrow::Update (GtkWidget* w) const
 {
 	WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (w), "data");
 	Theme *pTheme = pData->m_View->GetDoc ()->GetTheme ();
 	GnomeCanvasGroup* group = pData->Items[this];
 	if (!group) {
 		Add (w);
-		m_TypeChanged = false;
+		const_cast <ReactionArrow *> (this)->m_TypeChanged = false;
 		return;
 	}
 	if (m_TypeChanged) {
 		gtk_object_destroy (GTK_OBJECT (group));
+		pData->Items[this] = NULL;
 		Add (w);
-		m_TypeChanged = false;
+		const_cast <ReactionArrow *> (this)->m_TypeChanged = false;
 		return;
 	}
 	GnomeCanvasPoints *points = gnome_canvas_points_new (2);
@@ -411,6 +414,7 @@ void ReactionArrow::SetSelected (GtkWidget* w, int state)
 void ReactionArrow::AddProp (Object *object)
 {
 	Document *Doc = dynamic_cast<Document*> (GetDocument ());
+	WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (Doc->GetWidget ()), "data");
 	Operation *Op = Doc->GetNewOperation (GCP_MODIFY_OPERATION);
 	Op->AddObject (object, 0);
 	Object *Group = GetGroup ();
@@ -421,7 +425,18 @@ void ReactionArrow::AddProp (Object *object)
 	// add the child in the object tree
 	AddChild (prop);
 	// position the child
+	PositionChild (prop);
+	Op->AddObject (Group, 1);
+	Doc->FinishOperation ();
+	pData->UnselectAll ();
+	EmitSignal (OnChangedSignal);
+	new ReactionPropDlg (this, prop);
+}
+
+void ReactionArrow::PositionChild (ReactionProp *prop)
+{
 	// FIXME: this is experimental code
+	Document *Doc = dynamic_cast<Document*> (GetDocument ());
 	Theme *pTheme = Doc->GetTheme ();
 	double xmin, xspan, ymin, yspan,
 		length = sqrt (m_width * m_width + m_height * m_height),
@@ -472,19 +487,30 @@ void ReactionArrow::AddProp (Object *object)
 	// calculate the vector of the needed move
 	xmin = m_x + length * x + y * yspan - (rect.x0 + rect.x1) / 2. / pTheme->GetZoomFactor ();
 	ymin = m_y + length * y - x * yspan - (rect.y0 + rect.y1) / 2. / pTheme->GetZoomFactor ();
-	object->Move (xmin, ymin);
-	Op->AddObject (Group, 1);
-	Doc->FinishOperation ();
-	pData->UnselectAll ();
+	prop->Move (xmin, ymin);
 	Doc->GetView ()->Update (this);
-	EmitSignal (OnChangedSignal);
-	new ReactionPropDlg (this, prop);
 }
 
 bool ReactionArrow::OnSignal (SignalId Signal, Object *Child)
 {
 	if (Signal == OnChangedSignal) {
-		// FIXME: write this code
+		// for now we can have only one child property.
+		map<string, Object*>::iterator i;
+		ReactionProp *prop = dynamic_cast <ReactionProp *> (GetFirstChild (i));
+		if (prop != NULL)
+			PositionChild (prop);
+	}
+	return true;
+}
+
+bool ReactionArrow::SetProperty (unsigned property, char const *value)
+{
+	switch (property) {
+	case GCU_PROP_REACTION_ARROW_TYPE:
+		m_Type = (strcmp (value, "double"))? ReversibleArrow: SimpleArrow;
+		break;
+	default:
+		return Arrow::SetProperty (property, value);
 	}
 	return true;
 }
