@@ -27,6 +27,9 @@
 #include "document.h"
 #include "application.h"
 
+using namespace gcu;
+using namespace std;
+
 namespace gcp {
 
 Tool* pActiveTool = NULL;
@@ -39,7 +42,6 @@ Tool::Tool(Application *App, string Id)
 	m_pObject = NULL;
 	m_pItem = NULL;
 	m_bChanged = m_bPressed = false;
-	m_OptionDialog = NULL;
 	m_pData = NULL;
 }
 
@@ -63,9 +65,9 @@ bool Tool::OnClicked (View* pView, Object* pObject, double x, double y, unsigned
 	m_pGroup = gnome_canvas_root (GNOME_CANVAS (m_pWidget));
 	m_pBackground = m_pView->GetBackground ();
 	m_dZoomFactor = m_pView->GetZoomFactor ();
-	Object* pAtom;
+/*	Object* pAtom;
 	if (m_pObject && ((pAtom = m_pObject->GetAtomAt (m_x0 / m_dZoomFactor, m_y0 / m_dZoomFactor))))
-			m_pObject = pAtom;
+			m_pObject = pAtom;*/
 	m_bAllowed = true;
 	return OnClicked ();
 }
