@@ -28,7 +28,9 @@
 #include "tool.h"
 #include "tools.h"
 #include <gcu/gtkcomboperiodic.h>
-#include <goffice/gtk/go-combo-box.h>
+#ifndef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/gtk/go-combo-box.h>
+#endif
 #include <cstring>
 
 using namespace gcu;
@@ -66,7 +68,6 @@ Tools::Tools (Application *App):
 	m_Book = GTK_NOTEBOOK (glade_xml_get_widget (xml, "tools-book"));
 	GtkWidget *w = glade_xml_get_widget (xml, "mendeleiev");
 	gtk_combo_periodic_set_element (GTK_COMBO_PERIODIC (w), pApp->GetCurZ ());
-	go_combo_box_set_tearable (GO_COMBO_BOX (w), TearableMendeleiev);
 	g_signal_connect_swapped (G_OBJECT (w), "changed", G_CALLBACK (element_changed_cb), this);
 	w = glade_xml_get_widget (xml, "help-btn");
 	g_signal_connect_swapped (G_OBJECT (w), "clicked", G_CALLBACK (help_cb), this);
@@ -162,12 +163,6 @@ void Tools::OnElementChanged (int Z)
 		gtk_label_set_text (GTK_LABEL (icon), Element::Symbol (Z));
 }
 
-void Tools::Update (void)
-{
-	GtkWidget *w = glade_xml_get_widget (xml, "mendeleiev");
-	go_combo_box_set_tearable (GO_COMBO_BOX (w), TearableMendeleiev);
-}
-
 void Tools::OnHelp ()
 {
 	m_App->OnHelp (m_Tool->GetHelpTag ());
