@@ -28,8 +28,10 @@
 #include "view.h"
 #include "window.h"
 #include <gcu/filechooser.h>
-#include <goffice/utils/go-image.h>
-#include <gio/gio.h>
+#ifndef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/utils/go-image.h>
+#   include <gio/gio.h>
+#endif
 #include <glib/gi18n.h>
 #include <clocale>
 #include <map>
@@ -37,7 +39,7 @@
 using namespace gcu;
 using namespace std;
 
-gsvApplication::gsvApplication (): Application (_("GSpectrum"), DATADIR, "gspectrum-unstable")
+gsvApplication::gsvApplication (): Application (_("GSpectrum"), DATADIR, "gspectrum")
 {
 	SetImageWidth (600);
 }
@@ -78,7 +80,9 @@ bool gsvApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 		bool err = g_file_query_exists (file, NULL);
 		gint result = GTK_RESPONSE_YES;
 		if (err) {
-			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), filename);
+			char *unescaped = g_uri_unescape_string (filename, NULL);
+			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
+			g_free (unescaped);
 			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 			gtk_window_set_icon_name (GTK_WINDOW (Box), "gspectrum");
 			result = gtk_dialog_run (Box);
